@@ -25,8 +25,6 @@ class Client:
     ----------
     user_id: :class:`int`
         The user id of the bot.
-    shard_count: Optional[:class:`int`]
-        The amount of shards your bot has. Defaults to `1`.
     player: Optional[:class:`BasePlayer`]
         The class that should be used for the player. Defaults to ``DefaultPlayer``.
         Do not change this unless you know what you are doing!
@@ -55,19 +53,15 @@ class Client:
     """
     _event_hooks = defaultdict(list)
 
-    def __init__(self, user_id: int, shard_count: int = 1,
-                 player=DefaultPlayer, regions: dict = None, connect_back: bool = False):
+    def __init__(self, user_id: int, player=DefaultPlayer, regions: dict = None,
+                 connect_back: bool = False):
         if not isinstance(user_id, int):
             raise TypeError('user_id must be an int (got {}). If the type is None, '
                             'ensure your bot has fired "on_ready" before instantiating '
                             'the Lavalink client. Alternatively, you can hardcode your user ID.'
                             .format(user_id))
 
-        if not isinstance(shard_count, int):
-            raise TypeError('shard_count must be an int with a positive value.')
-
         self._user_id = str(user_id)
-        self._shard_count = str(shard_count)
         self.node_manager = NodeManager(self, regions)
         self.player_manager = PlayerManager(self, player)
         self._connect_back = connect_back
@@ -333,11 +327,25 @@ class Client:
         generic_hooks = Client._event_hooks['Generic']
         targeted_hooks = Client._event_hooks[type(event).__name__]
 
-        tasks = [hook(event) for hook in itertools.chain(generic_hooks, targeted_hooks)]
-        results = await asyncio.gather(*tasks, return_exceptions=True)
+        async def _hook_wrapper(hook, event):
+            try:
+                await hook(event)
+            except:  # noqa: E722 pylint: disable=bare-except
+                self._logger.exception('Event hook {} encountered an exception!'.format(hook.__name__))
+                #  According to https://stackoverflow.com/questions/5191830/how-do-i-log-a-python-error-with-debug-information
+                #  the exception information should automatically be attached here. We're just including a message for
+                #  clarity.
 
-        for index, result in enumerate(results):
-            if isinstance(result, Exception):
-                self._logger.warning('Event hook {} encountered an exception!'.format(tasks[index].__name__), result)
+        tasks = [_hook_wrapper(hook, event) for hook in itertools.chain(generic_hooks, targeted_hooks)]
+        await asyncio.wait(tasks)
 
         self._logger.debug('Dispatched {} to all registered hooks'.format(type(event).__name__))
+
+#         tasks = [hook(event) for hook in itertools.chain(generic_hooks, targeted_hooks)]
+#         results = await asyncio.gather(*tasks, return_exceptions=True)
+
+#         for index, result in enumerate(results):
+#             if isinstance(result, Exception):
+#                 self._logger.warning('Event hook {} encountered an exception!'.format(tasks[index].__name__), result)
+
+#         self._logger.debug('Dispatched {} to all registered hooks'.format(type(event).__name__))
