@@ -28,7 +28,6 @@ class WebSocket:
         self._resume_timeout = resume_timeout
         self._resuming_configured = False
 
-        self._shards = self._lavalink._shard_count
         self._user_id = self._lavalink._user_id
 
         self._closers = (aiohttp.WSMsgType.CLOSE,
@@ -46,9 +45,10 @@ class WebSocket:
         """ Attempts to establish a connection to Lavalink. """
         headers = {
             'Authorization': self._password,
-            'Num-Shards': self._shards,
-            'User-Id': str(self._user_id)
-        }
+            'User-Id': str(self._user_id),
+            'Client-Name': 'Lavalink.py',
+            'Num-Shards': '1'  # Legacy header that is no longer used. Here for compatibility.
+        }  # soonTM: User-Agent? Also include version in Client-Name as per optional implementation format.
 
         if self._resuming_configured and self._resume_key:
             headers['Resume-Key'] = self._resume_key
@@ -65,7 +65,7 @@ class WebSocket:
             try:
                 self._ws = await self._session.ws_connect('ws://{}:{}'.format(self._host, self._port), headers=headers,
                                                           heartbeat=60)
-            except (aiohttp.ClientConnectorError, aiohttp.WSServerHandshakeError) as ce:
+            except (aiohttp.ClientConnectorError, aiohttp.WSServerHandshakeError, aiohttp.ServerDisconnectedError) as ce:
                 if isinstance(ce, aiohttp.ClientConnectorError):
                     self._lavalink._logger.warning('[NODE-{}] Invalid response received; this may indicate that '
                                                    'Lavalink is not running, or is running on a port different '
